### Instructions for ZCAPM Python Package
Run the following to install the ZCAPM package  
```pip install ZCAPM```  

#### Example
This package is best used in conjuction with a Jupyter Notebook. For an example notebook use the file titled ```ZCAPM Jupyter Notebook.ipynb```. The example PDF and HTML files are printouts of this notebook.